# -*- coding: utf-8 -*-
# Coding: BY MOHAMED_OS


from Plugins.Extensions.IPTVPlayer.compat import urllib_quote_plus
from Plugins.Extensions.IPTVPlayer.components.ihost import (CBaseHostClass,
                                                            CHostBase)
from Plugins.Extensions.IPTVPlayer.components.iptvplayerinit import \
    TranslateTXT as _
from Plugins.Extensions.IPTVPlayer.tools.iptvtools import (E2ColoR, printDBG,
                                                           printExc)
from Plugins.Extensions.IPTVPlayer.tools.iptvtypes import strwithmeta


def GetConfigList():
    optionList = []
    return optionList


def gettytul():
    return 'VidPlay'


class VidPlay(CBaseHostClass):

    def __init__(self):
        CBaseHostClass.__init__(self, {'history': 'vidplay', 'cookie': 'vidplay.cookie'})

        self.MAIN_URL = 'https://vidplay.org/'
        self.DEFAULT_ICON_URL = 'https://i.ibb.co/NKvP32Z/vidplay.png'

        self.HEADER = self.cm.getDefaultHeader()
        self.AJAX_HEADER = self.HEADER
        self.AJAX_HEADER.update({'X-Requested-With': 'XMLHttpRequest'})
        self.defaultParams = {'header': self.HEADER, 'use_cookie': True, 'load_cookie': True, 'save_cookie': True, 'cookiefile': self.COOKIE_FILE}

    def getPage(self, baseUrl, addParams={}, post_data=None):
        if addParams == {}:
            addParams = dict(self.defaultParams)

        sts, data = self.cm.getPage(self.cm.ph.stdUrl(baseUrl), addParams, post_data)
        return sts, data

    def listMainMenu(self, cItem):
        printDBG("VidPlay.listMainMenu")
        MAIN_CAT_TAB = [
            {'category': 'movei', 'title': _('Movies'), 'icon': self.DEFAULT_ICON_URL, 'url': self.getFullUrl('/movies'), 'media_type': 'movie'},
            {'category': 'serie', 'title': _('Series'), 'icon': self.DEFAULT_ICON_URL, 'url': self.getFullUrl('/tv-shows'), 'media_type': 'tv'},
            {'category': 'highest', 'title': _('Highest Rated'), 'icon': self.DEFAULT_ICON_URL},
            {'category': 'popular', 'title': _('Popular'), 'icon': self.DEFAULT_ICON_URL},
            {'category': 'search', 'title': _('Search'), 'search_item': True},
            {'category': 'search_history', 'title': _('Search history'), }]
        self.listsTab(MAIN_CAT_TAB, cItem)

    def listCatItems(self, cItem, nextCategory):
        printDBG(f"VidPlay.listCatItems cItem[{cItem}]")
        category = self.currItem.get("category", '')

        if category == 'highest':
            NEW_CAT_TAB = [
                {'category': nextCategory, 'title': _('Top Rated Movies'), 'icon': self.DEFAULT_ICON_URL, 'url': self.getFullUrl('/movies/star-rating/')},
                {'category': nextCategory, 'title': _('Top Rated Series'), 'icon': self.DEFAULT_ICON_URL, 'url': self.getFullUrl('/tv-shows/star-rating/')}]
        elif category == 'popular':
            NEW_CAT_TAB = [
                {'category': nextCategory, 'title': _('Most Viewed Movies'), 'icon': self.DEFAULT_ICON_URL, 'url': self.getFullUrl('/movies/popular/')},
                {'category': nextCategory, 'title': _('Most Viewed Series'), 'icon': self.DEFAULT_ICON_URL, 'url': self.getFullUrl('/tv-shows/popular/')}]
        self.listsTab(NEW_CAT_TAB, cItem)

    def listItems(self, cItem, nextCategory):
        printDBG(f"VidPlay.listItems cItem[{cItem}]")
        page = cItem.get('page', 1)
        media_type = cItem.get('media_type', '')

        sts, data = self.getPage(cItem['url'])
        if not sts:
            return

        nextPage = self.cm.ph.getDataBeetwenMarkers(data, ('<ul', '>', 'pagination'), ('</ul', '>'), True)[1]
        nextPage = self.getFullUrl(self.cm.ph.getSearchGroups(nextPage, f'''href=['"]([^'^"]+?)['"][^>]*?>{page + 1}<''')[0])

        tmp = self.cm.ph.getDataBeetwenMarkers(data, ('<div', '>', 'browse-grid'), ('<footer', '>'), True)[1]
        tmp = self.cm.ph.getAllItemsBeetwenMarkers(tmp, ('<figure', '>', 'figured'), ('</figure', '>'))
        for item in tmp:
            icon = self.getFullIconUrl(self.cm.ph.getSearchGroups(item, '''data-src=['"]([^"^']+?)['"]''')[0])
            url = self.getFullUrl(self.cm.ph.getSearchGroups(item, '''href=['"]([^"^']+?)['"]''')[0])
            if not (title := self.cleanHtmlStr(self.cm.ph.getSearchGroups(item, '''alt=['"]([^"^']+?)['"]''')[0])):
                title = self.cleanHtmlStr(self.cm.ph.getSearchGroups(item, '''title['"].+?([^>]+?)[$<]''')[0])

            desc = self.ph.extract_desc(item, [('year', '''year['"].+?([^>]+?)[$<]'''), ('rating', '''fa fa-star['"].+?([^>]+?)[$<]''')])

            info = self.ph.std_title(title, desc=desc, with_ep=True)
            if title != '':
                title = info['title_display']
            desc = info['desc']

            params = dict(cItem)
            params.update({'category': nextCategory, 'good_for_fav': True, 'EPG': True, 'title': title, 'url': url, 'icon': self.cm.ph.stdUrl(icon), 'desc': desc, 'media_type': media_type})
            self.addDir(params)

        if nextPage != '':
            params = dict(cItem)
            params.update({'title': _("Next page"), 'url': nextPage, 'page': page + 1})
            self.addDir(params)

    def exploreItems(self, cItem):
        printDBG(f"VidPlay.exploreItems cItem[{cItem}]")
        media_type = cItem.get('media_type', '')

        sts, data = self.getPage(cItem['url'])
        if not sts:
            return
        cItem['prev_url'] = cItem['url']

        desc = self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(data, ('<div', '>', 'ploting'), ('</p', '>'), False)[1])

        if (Season := self.cm.ph.getDataBeetwenMarkers(data, ('<div', '>', 'epselector'), ('<section', '>'), True)[1]):
            tmpSeason = self.cm.ph.getAllItemsBeetwenMarkers(Season, ('<b', '>'), ('<br>', '</div>'))
            for sHtmlContent in tmpSeason:
                title = self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(sHtmlContent, ('<b', '>'), ('</b', '>'), False)[1])
                self.addMarker({'title': f"{E2ColoR('lime')} {title}", 'icon': cItem['icon'], 'desc': ''})
                tmp = self.cm.ph.getAllItemsBeetwenMarkers(sHtmlContent, ('<a', '>'), ('</a', '>'))
                for item in tmp:
                    url = self.getFullUrl(self.cm.ph.getSearchGroups(item, '''href=['"]([^"^']+?)['"]''')[0])
                    title = self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(item, ('href', '>'), ('<span', '>'), False)[1])

                    info = self.ph.std_title(title)
                    if title != '':
                        title = info['title_display']
                    otherInfo = f"{info['desc']}\n{desc}"

                    params = dict(cItem)
                    params.update({'category': 'listSeason', 'good_for_fav': True, 'EPG': True, 'title': title, 'url': url, 'icon': cItem['icon'], 'desc': otherInfo, 'media_type': media_type})
                    self.addVideo(params)
        else:
            params = dict(cItem)
            params.update({'good_for_fav': True, 'EPG': True, 'title': cItem['title'], 'url': cItem['url'], 'icon': cItem['icon'], 'desc': desc, 'media_type': media_type})
            self.addVideo(params)

    def listSearchResult(self, cItem, searchPattern, searchType):
        printDBG(f"VidPlay.listSearchResult cItem[{cItem}], searchPattern[{searchPattern}] searchType[{searchType}]")
        url = self.getFullUrl(f'/index.php?menu=search&query={urllib_quote_plus(searchPattern)}')
        params = {'name': 'category', 'good_for_fav': False, 'url': url}
        self.listItems(params, 'explore_item')

    def getLinksForVideo(self, cItem):
        printDBG(f"VidPlay.getLinksForVideo [{cItem}]")
        urlTab = []

        sts, data = self.getPage(cItem['url'])
        if not sts:
            return
        cUrl = self.cm.meta['url']

        tmp = self.cm.ph.getDataBeetwenMarkers(data, ('<script>', 'document'), ('</script', '>'), True)[1]
        tmp = self.cm.ph.getAllItemsBeetwenMarkers(tmp, ('$', 'get'), ('function', '{'))
        for index, item in enumerate(tmp):
            url = self.getFullUrl(self.cm.ph.getSearchGroups(item, '''get\(['"]([^"^']+?)['"]''')[0])
            embed = self.cleanHtmlStr(self.cm.ph.getSearchGroups(item, '''embed.+?['"]([^"^']+?)['"]''')[0])

            params = dict(self.defaultParams)
            params['header'] = dict(self.AJAX_HEADER)
            params['header']['Referer'] = cItem['url']

            mainUrl = f'{url}?embed={embed}'
            sts, data = self.getPage(mainUrl, params)
            if not sts:
                return

            iFrame = self.getFullUrl(self.cm.ph.getSearchGroups(data, '''<iframe[^>]+?src=['"]([^"^']+?)['"]''', 1, ignoreCase=True)[0])

            index += 1
            if any(x in url for x in ['mov_vplay', 'tv_vplay']):
                title = (f"{cItem['title']} {E2ColoR('lightred')} [server {index}]{E2ColoR('white')}{E2ColoR('yellow')} - {self.up.getHostName(iFrame)}{E2ColoR('white')}")
            elif 'get_trailerz' in url:
                title = f"[{E2ColoR('yellow')}Trailer{E2ColoR('white')}]"
            else:
                title = 'server'

            urlTab.append({'name': title, 'url': strwithmeta(iFrame, {'Referer': cUrl}), 'need_resolve': 1})

        return urlTab

    def getVideoLinks(self, videoUrl):
        printDBG(f"VidPlay.getVideoLinks [{videoUrl}]")

        if self.cm.isValidUrl(videoUrl):
            return self.up.getVideoLinkExt(videoUrl)

    def getArticleContent(self, cItem):
        printDBG(f"VidPlay.getArticleContent [{cItem}]")
        otherInfo = {}

        mainUrl = cItem['url']
        if 'prev_url' in cItem:
            mainUrl = cItem['prev_url']

        sts, data = self.getPage(mainUrl)
        if not sts:
            return

        tmp = self.cm.ph.getDataBeetwenMarkers(data, ('<div', '>', 'center-block col-lg-12'), ('<section', '>'), True)[1]

        if not (desc := self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(tmp, ('<div', '>', 'ploting'), ('</p', '>'), False)[1])):
            desc = cItem['desc']

        if Info := self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(tmp, ('Rating', '>'), ('</a', '>'), False)[1]):
            otherInfo['imdb_rating'] = Info

        if Info := self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(tmp, ('Year', '>'), ('</a', '>'), False)[1]):
            otherInfo['year'] = Info

        if Info := self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(tmp, ('Country', '>'), ('</a', '>'), False)[1]):
            otherInfo['country'] = Info

        if Info := self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(tmp, ('Language', '>'), ('</a', '>'), False)[1]):
            otherInfo['language'] = Info

        if Info := self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(tmp, ('genres', '>'), ('</span', '>'), False)[1]):
            otherInfo['genre'] = Info

        if Info := self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(tmp, ('search-director', '>'), ('</a', '>'), False)[1]):
            otherInfo['director'] = Info

        if Info := self.cleanHtmlStr(self.cm.ph.getDataBeetwenNodes(tmp, ('search-star', '>'), ('<br', '>'), False)[1]):
            otherInfo['stars'] = Info

        return [{'title': cItem['title'], 'text': desc, 'images': [{'title': '', 'url': cItem['icon']}], 'other_info': otherInfo}]

    def handleService(self, index, refresh=0, searchPattern='', searchType=''):
        printDBG('handleService start')

        CBaseHostClass.handleService(self, index, refresh, searchPattern, searchType)

        name = self.currItem.get("name", '')
        category = self.currItem.get("category", '')
        printDBG(f"handleService: |||||||||||||||||||||||||||||||||||| name[{name}], category[{category}] ")
        self.currList = []

    # MAIN MENU
        if name is None and not category:
            self.listMainMenu({'name': 'category', 'type': 'category'})
        elif any(x in category for x in ['popular', 'highest']):
            self.listCatItems(self.currItem, 'listItems')
        elif any(x in category for x in ['movei', 'serie', 'listItems']):
            self.listItems(self.currItem, 'explore_item')
        elif category == 'explore_item':
            self.exploreItems(self.currItem)
    # SEARCH
        elif any(x in category for x in ['search', 'search_next_page']):
            cItem = dict(self.currItem)
            cItem.update({'search_item': False, 'name': 'category'})
            self.listSearchResult(cItem, searchPattern, searchType)
    # HISTORIA SEARCH
        elif category == "search_history":
            self.listsHistory({'name': 'history', 'category': 'search'}, 'desc', _("Type: "))
        else:
            printExc()

        CBaseHostClass.endHandleService(self, index, refresh)


class IPTVHost(CHostBase):

    def __init__(self):
        CHostBase.__init__(self, VidPlay(), True, [])

    def withArticleContent(self, cItem):
        if 'prev_url' in cItem or cItem.get('category', '') == 'explore_item':
            return True
        return False
