# -*- coding: utf-8 -*-
# https://github.com/Kodi-vStream/venom-xbmc-addons
#

from Components.config import config
from Plugins.Extensions.IPTVPlayer.libs.vstream.hosters.hoster import iHoster
from Plugins.Extensions.IPTVPlayer.libs.vstream.hosters.uptostream import \
    cHoster as uptostreamHoster
from Plugins.Extensions.IPTVPlayer.libs.vstream.lib.comaddon import (
    VSlog, dialog, siteManager)
from Plugins.Extensions.IPTVPlayer.libs.vstream.lib.handler.premiumHandler import \
    cPremiumHandler
from Plugins.Extensions.IPTVPlayer.libs.vstream.lib.handler.requestHandler import \
    cRequestHandler
from Plugins.Extensions.IPTVPlayer.libs.vstream.sites import siteuptobox


class cHoster(iHoster):

    def __init__(self):
        iHoster.__init__(self, 'uptobox', 'Uptobox', 'violet')
        self.oPremiumHandler = None

    def setUrl(self, url):
        self._url = str(url)
        self._url = self._url.replace('iframe/', '')
        self._url = self._url.replace('http:', 'https:')
        self._url = self._url.split('?aff_id')[0]

    def checkUrl(self, sUrl):
        return True

    def getMediaLink(self):
        self.oPremiumHandler = cPremiumHandler(self.getPluginIdentifier())
        if self.oPremiumHandler.isPremiumModeAvailable():

            try:
                mDefault = int(config.plugins.iptvplayer.uptobox_mode_default.value)
            except AttributeError:
                mDefault = 0

            if mDefault == 0:
                ret = dialog().VSselect(['Passer en Streaming (via Uptostream)', 'Rester en direct (via Uptobox)'], 'Choissisez votre mode de fonctionnement')
            else:
                # 0 is ask me, so 1 is uptostream and so on...
                ret = mDefault - 1

            # mode stream
            if ret == 0:
                return self._getMediaLinkForGuest()
            # mode DL
            if ret == 1:
                return self._getMediaLinkByPremiumUser()

            return False

        else:
            VSlog('UPTOBOX - no premium')
            return self._getMediaLinkForGuest()

    def _getMediaLinkForGuest(self):
        URL_MAIN = siteManager().getUrlMain(siteuptobox.SITE_IDENTIFIER)
        site_extension = f".{URL_MAIN.split('.')[1]}"

        self._url = self._url.replace('uptobox.com/', f'uptostream{site_extension}')
        self._url = self._url.replace('uptobox.eu/', f'uptostream{site_extension}')
        self._url = self._url.replace('uptobox.link/', f'uptostream{site_extension}')
        self._url = self._url.replace('/uptobox.', '/uptostream.')

        # On redirige vers le hoster uptostream
        oHoster = uptostreamHoster()
        oHoster.setUrl(self._url)
        return oHoster.getMediaLink()

    def _getMediaLinkByPremiumUser(self):

        if not (token := self.oPremiumHandler.getToken()):
            return self._getMediaLinkForGuest()

        URL_MAIN = siteManager().getUrlMain(siteuptobox.SITE_IDENTIFIER)
        site_extension = f".{URL_MAIN.split('.')[1]}"
        fileCode = self._url.split('/')[-1].split('?')[0]
        url1 = f"{URL_MAIN}api/link?token={token}&file_code={fileCode}"
        try:
            oRequestHandler = cRequestHandler(url1)
            dict_liens = oRequestHandler.request(jsonDecode=True)
            statusCode = dict_liens["statusCode"]
            if statusCode == 0:  # success
                sUrl = dict_liens["data"]["dlLink"]
                sUrl = sUrl.replace('.com/', site_extension)
                return True, sUrl

            if statusCode == 16:  # Waiting needed
                status = "Pas de compte Premium"  # dict_liens["data"]["waiting"]
            elif statusCode == 7:  # Invalid parameter
                status = f'{dict_liens["message"]} : {dict_liens["data"]}'
            else:
                status = f'Erreur inconnue : {str(statusCode)}, message = {dict_liens["message"]} : {str(dict_liens["data"])}'
        except Exception as e:
            status = e

        VSlog(f'UPTOBOX - {str(status)}')

        return False
